package com.business.service;

import java.util.List;
import com.business.domain.BusGridPersonInfo;

/**
 * 网格人员管理Service接口
 * 
 * @author lei_wang
 * @date 2020-07-29
 */
public interface IBusGridPersonInfoService 
{
    /**
     * 查询网格人员管理
     * 
     * @param gridPersonId 网格人员管理ID
     * @return 网格人员管理
     */
    public BusGridPersonInfo selectBusGridPersonInfoById(Long gridPersonId);

    /**
     * 查询网格人员管理列表
     * 
     * @param busGridPersonInfo 网格人员管理
     * @return 网格人员管理集合
     */
    public List<BusGridPersonInfo> selectBusGridPersonInfoList(BusGridPersonInfo busGridPersonInfo);

    /**
     * 新增网格人员管理
     * 
     * @param busGridPersonInfo 网格人员管理
     * @return 结果
     */
    public int insertBusGridPersonInfo(BusGridPersonInfo busGridPersonInfo);

    /**
     * 修改网格人员管理
     * 
     * @param busGridPersonInfo 网格人员管理
     * @return 结果
     */
    public int updateBusGridPersonInfo(BusGridPersonInfo busGridPersonInfo);

    /**
     * 批量删除网格人员管理
     * 
     * @param ids 需要删除的数据ID
     * @return 结果
     */
    public int deleteBusGridPersonInfoByIds(String ids);

    /**
     * 删除网格人员管理信息
     * 
     * @param gridPersonId 网格人员管理ID
     * @return 结果
     */
    public int deleteBusGridPersonInfoById(Long gridPersonId);
}
